<?php
/**
 * The main theme functions file loads styles/scripts, allows some theme functionality and provides some helper functions.
 */
/**
 * This theme only works in WordPress 4.2 or later.
 */

if ( version_compare( $GLOBALS['wp_version'], '4.2', '<' ) ) {
    require get_template_directory() . '/inc/back-compat.php';
}

if ( ! isset( $content_width ) ) $content_width = 1170;


function getAssetsPath($path) {
    return get_template_directory_uri() . '/assets/' . $path;
}

function image($name) {
    return getAssetsPath('img/'.$name);
}

	/**
	 * Enqueue scripts and styles.
	 *
	 */
	function truewest_scripts() {
		global $wp_styles;
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );
	
		// Loads our bootstrap.
		wp_enqueue_style( 'truewest-bootstrap-style', getAssetsPath('bootstrap/css/bootstrap.min.css') );

		// Adds bootstrap JavaScript.
		wp_enqueue_script( 'truewest-bootstrap-js',getAssetsPath('bootstrap/js/bootstrap.min.js'), array( 'jquery' ) );
	
		// Loads our main stylesheet.
		wp_enqueue_style( 'truewest-style', get_stylesheet_uri() );
		
		/* Menu */
  		// Adds bootstrap JavaScript.
		wp_enqueue_script( 'truewest-menu-js',getAssetsPath('menu/script.js'), array( 'jquery' ) );
		wp_enqueue_style( 'truewest-menu-style',getAssetsPath('menu/styles.css'));
	
       	
     
		//Load Font CSS
		wp_enqueue_style('font-awesome.min', getAssetsPath('custom/css/font-awesome.min.css'));
		
		/* OWL */
		// Loads stylesheets.
			wp_enqueue_style( 'truewest-owl-style', getAssetsPath('owl-carousel/owl.carousel.css'));
			wp_enqueue_style( 'truewest-owl-theme', getAssetsPath('owl-carousel/owl.theme.css'));
			// OWL JS
			wp_enqueue_script( 'truewest-owl',  getAssetsPath('owl-carousel/owl.carousel.js'));
	
		// Custom JS
		wp_enqueue_script( 'truewest-custom',  getAssetsPath('custom/js/custom.min.js'));
		
		// Gallery Page
		if ( is_page_template( 'page-templates/gallery.php' ) ) {
			wp_enqueue_style( 'truewest-portfolio-compenent',  getAssetsPath('portfolio/css/component.css'));
			wp_enqueue_script( 'truewest-modernizr',  getAssetsPath('portfolio/js/modernizr.custom.js'));
			wp_enqueue_script( 'truewest-masonry',  getAssetsPath('portfolio/js/masonry.pkgd.min.js')); 
			wp_enqueue_script( 'truewest-imagesloaded',  getAssetsPath('portfolio/js/imagesloaded.js'));
			wp_enqueue_script( 'truewest-classie',  getAssetsPath('portfolio/js/classie.js'));
			wp_enqueue_script( 'truewest-AnimOnScroll',  getAssetsPath('portfolio/js/AnimOnScroll.js'));
			wp_enqueue_script( 'truewest-fancybox',  getAssetsPath('fancybox/js/jquery.fancybox.js'));
			wp_enqueue_script( 'truewest-fancybox-buttons',  getAssetsPath('fancybox/js/jquery.fancybox-buttons.js'));
			wp_enqueue_script( 'truewest-fancybox-thumbs',  getAssetsPath('fancybox/js/jquery.fancybox-thumbs.js'));
			wp_enqueue_script( 'truewest-easing-pack',  getAssetsPath('fancybox/js/jquery.easing-1.3.pack.js'));
			wp_enqueue_script( 'truewest-mousewheel',  getAssetsPath('fancybox/js/jquery.mousewheel-3.0.6.pack.js'));
			wp_enqueue_style( 'truewest-fancybox-buttons',  getAssetsPath('fancybox/css/jquery.fancybox-buttons.css'));
			wp_enqueue_style( 'truewest-fancybox-thumbs-css',  getAssetsPath('fancybox/css/jquery.fancybox-thumbs.css'));
			wp_enqueue_style( 'truewest-fancybox-css',  getAssetsPath('fancybox/css/jquery.fancybox.css'));
		}		
		// Contact Page
		if ( is_page_template( 'page-templates/contact.php' ) && get_theme_mod('google_map_active', 1) ) {
				wp_enqueue_script( 'truewest-google-js',  'https://maps.googleapis.com/maps/api/js?v=3.exp');
	
			}	
		}
	
	add_action( 'wp_enqueue_scripts', 'truewest_scripts' );

	// Add Open Sans Google font
	function truewest_add_google_fonts() {
				
				wp_register_style('truewest-googleFonts-Montserrat', 'http://fonts.googleapis.com/css?family=Montserrat');
	 			wp_enqueue_style('truewest-googleFonts-Montserrat');
	
				wp_register_style('truewest-googleFonts-OpenSans', 'http://fonts.googleapis.com/css?family=Open+Sans');
	 			wp_enqueue_style('truewest-googleFonts-OpenSans');
	
			}
	 
	add_action('wp_print_styles', 'truewest_add_google_fonts');


    //Navigation Menus
    register_nav_menus(array(
        'primary' => __('Primary Menu', 'truewest')
    ));

    //Add featured image support
    add_theme_support('post-thumbnails');

    //This feature enables plugins and themes to manage the document title tag.
    add_theme_support('title-tag');
	
    //This feature adds RSS feed links to HTML <head>.
    add_theme_support( 'automatic-feed-links' );
 

	add_theme_support('post-thumbnails');
	set_post_thumbnail_size( 710, 300, true ); 
 
	//Customize excerpt word count
	function custom_excerpt_length() {
		return 50; //50 words
	}
	
	add_filter('excerpt_length', 'custom_excerpt_length');

//Add our Widget Locations
function truewest_WidgetsInit() {

    register_sidebar(array(
        'name' => __('Footer Area', 'truewest'),
        'id' => 'footer_area',
   		'before_widget' => '<aside id="%1$s" class="footer_widget col-md-4 %2$s"  itemscope itemtype="http://schema.org/WPFooter">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title heading" itemprop="about">',
		'after_title'   => '</h3>',
    ));
    register_sidebar(array(
        'name' => __('Default Widget Area', 'truewest'),
        'id' => 'sidebar',
   		'before_widget' => '<aside id="%1$s" class="sidebar_widget %2$s"  itemscope itemtype="http://schema.org/WPSideBar">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title heading" itemprop="about">',
		'after_title'   => '</h3>',
    ));
 

}

add_action('widgets_init', 'truewest_WidgetsInit');

/*----------------------------
	 Add image sizes 
 -----------------------------*/
add_image_size ( 'slider_image', 1100, 611, true);
add_image_size ( 'aboutus_image', 1100, 550, true);
add_image_size ( 'services_image', 325, 200, true);
add_image_size ( 'gallery-image', 313, 284, true);
add_image_size ( 'team_image_thumb', 217, 214, true);
add_image_size ( 'contact_image', 521, 600, true);

//add_image_size ( 'logo', 130, 32);



/*---------------------------------------------
	 Custom Fucntions
----------------------------------------------*/
include_once( dirname( __FILE__ ) . '/theme-options.php' );
include('navthemes_fuctions.php');
